@@ -1,7 +1,7 @@
 /*
- *  $Id: test.cpp,v 1.13 2000/10/15 15:59:53 sbooth Exp $
+ *  $Id: test.cpp,v 1.18 2002/03/03 17:41:44 sbooth Exp $
  *
- *  Copyright (C) 1996, 1997, 1998, 1999, 2000 Stephen F. Booth
+ *  Copyright (C) 1996 - 2002 Stephen F. Booth
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,6 +18,12 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+/*! \file test.cpp
+ * \brief GNU %cgicc test application
+ *
+ * Tests and demonstrates access of form data using the GNU %cgicc library.
+ */
+
 #include <new>
 #include <string>
 #include <vector>
@@ -27,6 +33,7 @@
 
 #include "cgicc/CgiDefs.h"
 #include "cgicc/Cgicc.h"
+#include "cgicc/HTTPHTMLHeader.h"
 #include "cgicc/HTMLClasses.h"
 
 #if HAVE_UNAME
@@ -56,7 +63,6 @@
 void dumpEnvironment(const CgiEnvironment& env);
 void dumpList(const Cgicc& formData);
 void showForm(const Cgicc& formData);
-void showFile(const Cgicc& formData);
 
 // Main Street, USA
 int
@@ -78,7 +84,7 @@ main(int /*argc*/,
     
     // Output the HTTP headers for an HTML document, and the HTML 4.0 DTD info
     cout << HTTPHTMLHeader() << HTMLDoctype(HTMLDoctype::eStrict) << endl;
-    cout << html().set("lang", "EN").set("dir", "LTR") << endl;
+    cout << html().set("lang", "en").set("dir", "ltr") << endl;
 
     // Set up the page's header and title.
     // I will put in lfs to ease reading of the produced HTML. 
@@ -86,36 +92,34 @@ main(int /*argc*/,
 
     // Output the style sheet portion of the header
     cout << style() << comment() << endl;
-    cout << "BODY { color: black; background-color: white; }" << endl;
-    cout << "HR.half { width: 60%; align: center; }" << endl;
-    cout << "SPAN.red, STRONG.red { color: red; }" << endl;
-    cout << "DIV.smaller { font-size: small; }" << endl;
-    cout << "DIV.notice { border: solid thin; padding: 1em; margin: 1em 0; "
-	 << "background: #DDD; }" << endl;
-    cout << "SPAN.blue { color: blue; }" << endl;
-    cout << "COL.title { color: white; background-color: black; ";
+    cout << "body { color: black; background-color: white; }" << endl;
+    cout << "hr.half { width: 60%; align: center; }" << endl;
+    cout << "span.red, strong.red { color: red; }" << endl;
+    cout << "div.smaller { font-size: small; }" << endl;
+    cout << "div.notice { border: solid thin; padding: 1em; margin: 1em 0; "
+	 << "background: #ddd; }" << endl;
+    cout << "span.blue { color: blue; }" << endl;
+    cout << "col.title { color: white; background-color: black; ";
     cout << "font-weight: bold; text-align: center; }" << endl;
-    cout << "COL.data { background-color: #DDD; text-align: left; }" << endl;
-    cout << "TD.data, TR.data { background-color: #DDD; text-align: left; }"
+    cout << "col.data { background-color: #DDD; text-align: left; }" << endl;
+    cout << "td.data, tr.data { background-color: #ddd; text-align: left; }"
 	 << endl;
-    cout << "TD.grayspecial { background-color: #DDD; text-align: left; }"
+    cout << "td.grayspecial { background-color: #ddd; text-align: left; }"
 	 << endl;
-    cout << "TD.ltgray, TR.ltgray { background-color: #DDD; }" << endl;
-    cout << "TD.dkgray, TR.dkgray { background-color: #BBB; }" << endl;
-    cout << "COL.black, TD.black, TD.title, TR.title { color: white; " 
+    cout << "td.ltgray, tr.ltgray { background-color: #ddd; }" << endl;
+    cout << "td.dkgray, tr.dkgray { background-color: #bbb; }" << endl;
+    cout << "col.black, td.black, td.title, tr.title { color: white; " 
 	 << "background-color: black; font-weight: bold; text-align: center; }"
 	 << endl;
-    cout << "COL.gray, TD.gray { background-color: #DDD; text-align: center; }"
+    cout << "col.gray, td.gray { background-color: #ddd; text-align: center; }"
 	 << endl;
-    cout << "TABLE.cgi { left-margin: auto; right-margin: auto; width: 90%; }"
+    cout << "table.cgi { left-margin: auto; right-margin: auto; width: 90%; }"
 	 << endl;
 
     cout << comment() << style() << endl;
 
     cout << title() << "GNU cgicc v" << cgi.getVersion() << " Test Results" 
 	 << title() << endl;
-    cout << meta().set("name", "author").set("content", "Stephen F. Booth") 
-	 << endl;
 
     cout << head() << endl;
     
@@ -176,12 +180,6 @@ main(int /*argc*/,
     if(cgi.queryCheckbox("showForm"))
       showForm(cgi);
 
-    // If the user requested information on the uploaded file,
-    // create a simple table showing the information
-    // Disabled for demo
-    if(cgi.queryCheckbox("showFile"))
-      showFile(cgi);
-
     // Now print out a footer with some fun info
     cout << p() << CGICCNS div().set("align","center");
     cout << a("Back to form").set("href", cgi.getEnvironment().getReferrer()) 
@@ -191,10 +189,7 @@ main(int /*argc*/,
     // Information on cgicc
     cout << CGICCNS div().set("align","center").set("class","smaller") << endl;
     cout << "GNU cgi" << span("cc").set("class","red") << " v";
-    cout << cgi.getVersion();
-    cout << " by " << a("Stephen F. Booth")
-                       .set("href", "http://home.earthlink.net/~sfbooth/") 
-	 << br() << endl;
+    cout << cgi.getVersion() << br() << endl;
     cout << "Compiled at " << cgi.getCompileTime();
     cout << " on " << cgi.getCompileDate() << br() << endl;
 
@@ -245,7 +240,7 @@ main(int /*argc*/,
 
     // Output the HTTP headers for an HTML document, and the HTML 4.0 DTD info
     cout << HTTPHTMLHeader() << HTMLDoctype(HTMLDoctype::eStrict) << endl;
-    cout << html().set("lang","EN").set("dir","LTR") << endl;
+    cout << html().set("lang","en").set("dir","ltr") << endl;
 
     // Set up the page's header and title.
     // I will put in lfs to ease reading of the produced HTML. 
@@ -253,22 +248,20 @@ main(int /*argc*/,
 
     // Output the style sheet portion of the header
     cout << style() << comment() << endl;
-    cout << "BODY { color: black; background-color: white; }" << endl;
-    cout << "HR.half { width: 60%; align: center; }" << endl;
-    cout << "SPAN.red, STRONG.red { color: red; }" << endl;
-    cout << "DIV.notice { border: solid thin; padding: 1em; margin: 1em 0; "
-	 << "background: #DDD; }" << endl;
+    cout << "body { color: black; background-color: white; }" << endl;
+    cout << "hr.half { width: 60%; align: center; }" << endl;
+    cout << "span.red, STRONG.red { color: red; }" << endl;
+    cout << "div.notice { border: solid thin; padding: 1em; margin: 1em 0; "
+	 << "background: #ddd; }" << endl;
 
     cout << comment() << style() << endl;
 
     cout << title("GNU cgicc exception") << endl;
-    cout << meta().set("name", "author")
-		  .set("content", "Stephen F. Booth") << endl;
     cout << head() << endl;
     
     cout << body() << endl;
     
-    cout << h1() << "GNU Cgi" << span("cc", set("class","red"))
+    cout << h1() << "GNU cgi" << span("cc", set("class","red"))
 	 << " caught an exception" << h1() << endl; 
   
     cout << CGICCNS div().set("align","center").set("class","notice") << endl;
@@ -428,13 +421,13 @@ showForm(const Cgicc& formData)
     cout << "You haven't wasted any time on the web." << br() << endl;
 
   // getElement and getStrippedValue
-  const_form_iterator sheep = formData.getElement("sheep");
-  if(sheep != (*formData).end() && ! (*sheep).isEmpty()) {
-    STDNS string temp = (*sheep).getStrippedValue();
-    cout << "Your thoughts about sheep cloning: " << temp << br() << endl;
+  const_form_iterator thoughts = formData.getElement("thoughts");
+  if(thoughts != (*formData).end() && ! (*thoughts).isEmpty()) {
+    STDNS string temp = (*thoughts).getStrippedValue();
+    cout << "Your thoughts : " << temp << br() << endl;
   }
   else
-    cout << "You don't have any thoughts about sheep!?" << br() << endl;
+    cout << "You don't have any thoughts!?" << br() << endl;
   
   // queryCheckbox
   if(formData.queryCheckbox("hungry"))
@@ -491,51 +484,3 @@ showForm(const Cgicc& formData)
   
   cout << CGICCNS div() << endl;
 }
-
-// Show the uploaded file
-// This will work if you uncomment the appropriate lines in testform.html
-void
-showFile(const Cgicc& formData) 
-{
-  cout << h2("File Uploaded via FormFile") << endl;
-  
-  const_file_iterator file;
-  file = formData.getFile("userfile");
-				
-  if(file != formData.getFiles().end()) {
-    cout << CGICCNS div().set("align","center") << endl;
-    
-    cout << table().set("border","0").set("rules","none").set("frame","void")
-		   .set("cellspacing","2").set("cellpadding","2")
-		   .set("class","cgi") << endl;
-    cout << colgroup().set("span","2") << endl;
-    cout << col().set("align","center").set("class","title").set("span","1") 
-	 << endl;
-    cout << col().set("align","left").set("class","data").set("span","1") 
-	 << endl;
-    cout << colgroup() << endl;
-    
-    cout << tr() << td("Name").set("class","title")
-	 << td((*file).getName()).set("class","data") << tr() << endl;
-
-    cout << tr() << td("Data Type").set("class","title")
-	 << td((*file).getDataType()).set("class","data") << tr() << endl;
-    
-    cout << tr() << td("Filename").set("class","title") 
-	 << td((*file).getFilename()).set("class","data") << tr() << endl;
-    cout << tr() << td("Data Length").set("class","title") 
-	 << td().set("class","data") << (*file).getDataLength() 
-	 << td() << tr() << endl;
-    
-    cout << tr() << td("File Data").set("class","title")
-	 << td().set("class","data") << pre();
-    (*file).writeToStream(cout);
-    cout << pre() << td() << tr() << endl;
-    
-    cout << table() << CGICCNS div() << endl;
-  }
-  else {
-    cout << p() << CGICCNS div().set("class", "notice") << endl;
-    cout << "No file was uploaded." << endl << CGICCNS div() << p() << endl;
-  }
-}
